@@ -9,7 +9,7 @@
         <location filename="mainwindow.cpp" line="1197"/>
         <location filename="ui_mainwindow.h" line="433"/>
         <source>Package Installer</source>
-        <translation>Pakettien asennus</translation>
+        <translation>Pakettien asennusohjelma</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="42"/>
@@ -52,7 +52,7 @@
         <location filename="mainwindow.ui" line="108"/>
         <location filename="ui_mainwindow.h" line="439"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Manage popular packages&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Greyed out items have already been installed.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Hallitse suosittuja paketteja&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Harmaannetut kohteet on jo asennettu.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
+        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Hallitse suosittuja paketteja&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Harmaalla olevat kohteet on jo asennettu.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="138"/>
@@ -78,7 +78,7 @@
         <location filename="mainwindow.cpp" line="1282"/>
         <location filename="ui_mainwindow.h" line="443"/>
         <source>MX Test Repo</source>
-        <translation>MX Testiohjelmalähde</translation>
+        <translation>MX Test pakettivarasto</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="170"/>
